Struct DataFileBuilderV2

pub struct DataFileBuilderV2 { /* private fields */ }
Builder for DataFile.

Implementations

Source

impl DataFileBuilderV2

pub fn with_content(&mut self, value: DataContentType) -> &mut Self

field id: 134

Type of content stored by the data file: data, equality deletes, or position deletes (all v1 files are data files)

pub fn with_file_path(&mut self, value: String) -> &mut Self

field id: 100

Full URI for the file with FS scheme

pub fn with_file_format(&mut self, value: DataFileFormat) -> &mut Self

field id: 101

String file format name, avro, orc or parquet

pub fn with_partition(&mut self, value: StructValue) -> &mut Self

field id: 102

Partition data tuple, schema based on the partition spec output using partition field ids for the struct field ids

pub fn with_record_count(&mut self, value: i64) -> &mut Self

field id: 103

Number of records in this file

pub fn with_file_size_in_bytes(&mut self, value: i64) -> &mut Self

field id: 104

Total file size in bytes

pub fn with_column_sizes(&mut self, value: HashMap<i32, i64>) -> &mut Self

field id: 108 key field id: 117 value field id: 118

Map from column id to the total size on disk of all regions that store the column. Does not include bytes necessary to read other columns, like footers. Leave null for row-oriented formats (Avro)

pub fn with_value_counts(&mut self, value: HashMap<i32, i64>) -> &mut Self

field id: 109 key field id: 119 value field id: 120

Map from column id to number of values in the column (including null and NaN values)

pub fn with_null_value_counts(&mut self, value: HashMap<i32, i64>) -> &mut Self

field id: 110 key field id: 121 value field id: 122

Map from column id to number of null values in the column

pub fn with_nan_value_counts(&mut self, value: HashMap<i32, i64>) -> &mut Self

field id: 137 key field id: 138 value field id: 139

Map from column id to number of NaN values in the column

pub fn with_distinct_counts(&mut self, value: HashMap<i32, i64>) -> &mut Self

field id: 111 key field id: 123 value field id: 124

Map from column id to number of distinct values in the column; distinct counts must be derived using values in the file by counting or using sketches, but not using methods like merging existing distinct counts

pub fn with_lower_bounds(&mut self, value: HashMap<i32, Vec<u8>>) -> &mut Self

field id: 125 key field id: 126 value field id: 127

Map from column id to lower bound in the column serialized as binary. Each value must be less than or equal to all non-null, non-NaN values in the column for the file.

Reference:

pub fn with_upper_bounds(&mut self, value: HashMap<i32, Vec<u8>>) -> &mut Self

field id: 128 key field id: 129 value field id: 130

Map from column id to upper bound in the column serialized as binary. Each value must be greater than or equal to all non-null, non-Nan values in the column for the file.

Reference:

pub fn with_key_metadata(&mut self, value: Option<Vec<u8>>) -> &mut Self

field id: 131

Implementation-specific key metadata for encryption

pub fn with_split_offsets(&mut self, value: Vec<i64>) -> &mut Self

field id: 132 element field id: 133

Split offsets for the data file. For example, all row group offsets in a Parquet file. Must be sorted ascending

pub fn with_equality_ids(&mut self, value: Vec<i32>) -> &mut Self

field id: 135 element field id: 136

Field ids used to determine row equality in equality delete files. Required when content is EqualityDeletes and should be null otherwise. Fields with ids listed in this column must be present in the delete file

pub fn with_sort_order_id(&mut self, value: i32) -> &mut Self

field id: 140

ID representing sort order for this file.

If sort order ID is missing or unknown, then the order is assumed to be unsorted. Only data files and equality delete files should be written with a non-null order id. Position deletes are required to be sorted by file and position, not a table order, and should set sort order id to null. Readers must ignore sort order id for position delete files.

pub fn build(&self) -> Result<DataFile, DataFileBuilderV2Error>

Builds a new DataFile.

Errors

If a required field has not been initialized.