pub struct PartitionField {
pub source_column_id: i32,
pub partition_field_id: i32,
pub transform: Transform,
pub name: String,
}Expand description
Field of the specified partition spec.
Fields
source_column_id: i32A source column id from the table’s schema
partition_field_id: i32A partition field id that is used to identify a partition field and is unique within a partition spec.
In v2 table metadata, it is unique across all partition specs.
transform: TransformA transform that is applied to the source column to produce a partition value
The source column, selected by id, must be a primitive type and cannot be contained in a map or list, but may be nested in a struct.
name: StringA partition name